*******************************************************************附录部分*******************************************************
//表Ⅲ1  关税不完全传递下的福利效应
//定义参数的可能取值
local eta_values 0.7 0.8 0.9   //进口关税传递率取值
local kappa_values 0.1 0.15 0.2     //国产品价格加成的传递率取值
//初始化空数据集，用于存储所有结果
tempfile master_results
clear
set obs 10
gen group= _n
save `master_results', emptyok
clear
foreach eta in `eta_values' {
    foreach kappa in `kappa_values' {
		use uhs1, clear
		local eta_str : subinstr local eta "." "", all
        local kappa_str : subinstr local kappa "." "", all
        gen eta = `eta'
        gen kappa = `kappa'

        merge m:1 m using temp\temp_SM.dta, nogen
        merge m:1 m using temp\temp_tfinal.dta, nogen
        merge m:1 m using temp\temp_SD.dta, nogen
        merge m:1 m using temp\temp_tinput.dta, nogen
        merge m:1 m using temp\temp_tinputd.dta, nogen 
        aorder
        forv i=1/145 {
            gen welfare_`eta_str'_`kappa_str'_`i' = ///
               -(`eta'*share`i'*SM`i' + `kappa'*share`i'*SD`i')*tfinal`i' - ///
                share`i'*SD`i'*(`eta'*tinput`i' + `kappa'*tinputd`i')
        }
        aorder
        egen welfare_`eta_str'_`kappa_str' = rowtotal(welfare_`eta_str'_`kappa_str'_1-welfare_`eta_str'_`kappa_str'_145)
        xtile group = logincome, nq(10)
        bysort group: egen wm_`eta_str'_`kappa_str' = mean(welfare_`eta_str'_`kappa_str') 
		replace  wm_`eta_str'_`kappa_str'= wm_`eta_str'_`kappa_str'*100
        keep group  wm_`eta_str'_`kappa_str'
        duplicates drop

		merge 1:1 group using `master_results', nogen
        save `master_results', replace	
    }
}
list, clean



//图Ⅳ1允许进口中包含国内附加值的福利结果
local varlist p_m p_d 
foreach var in `varlist' {
    use robustdata1, clear
    sort ref
    keep `var'
    xpose, clear
    renvarlab v*, subst(v `var')
    gen m = "pipei"
    save temp\temp_`var'.dta, replace
}

use uhs1,clear
merge m:1 m using temp\temp_SM.dta,nogen
merge m:1 m using temp\temp_SD.dta,nogen
merge m:1 m using temp\temp_p_m.dta,nogen
merge m:1 m using temp\temp_p_d.dta,nogen
aorder
	forv i=1/145 {
	gen indirect`i'=-share`i'*SD`i'*p_d`i'
	//SDW*siw*P_D
	} 
	forv i=1/145 {
	gen direct`i'=-share`i'*SM`i'*p_m`i'
	//SMW*siw*P_M
	} 
aorder
egen direct=rowtotal(direct1-direct145)	
egen indirect=rowtotal(indirect1-indirect145)	
gen welfare=direct+indirect
xtile group=logincome,nq(10)
replace welfare=welfare*100 //百分数
replace direct=direct*100
replace indirect=indirect*100
keep group welfare direct indirect
bysort group:egen wm=mean(welfare)
bysort group:egen dm=mean(direct)
bysort group:egen im=mean(indirect)
drop welfare direct indirect
duplicates drop
list, clean
save results/附录4.dta,replace